translate.search

Package translate :: Package search |
[hide private]
[frames] | no frames]

# Package search

source code

translate.search is part of the Translate Toolkit. It provides services for searching and matching of text.

Submodules | [hide private]
translate.search.indexing: interface for differrent indexing engines for the translate toolkit translate.search.indexing.CommonIndexer: base class for interfaces to indexing engines for pootle translate.search.indexing.PyLuceneIndexer: interface for the PyLucene (v2.x) indexing engine translate.search.indexing.PyLuceneIndexer1: interface for the pylucene (v1.x) indexing engine translate.search.indexing.XapianIndexer: Interface to the Xapian indexing engine for the Translate Toolkit translate.search.lshtein: A class to calculate a similarity based on the Levenshtein distance. translate.search.match: Class to perform translation memory matching from a store of translation units translate.search.segment: Module to deal with different types and uses of segmentation translate.search.terminology: A class that does terminology matching

Variables | [hide private]
| __package__ = `None` hash(x)

Imports: lshtein, terminology